@@ -33,9 +33,7 @@
   $roleneeded = 1;
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/base_main.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/base_main.php");
 
   $page_title = _ROLEADMIN;
     
@@ -98,7 +96,7 @@
       $role = new BaseRole();
       $rolearray = array(filterSql($_POST['role_id']), filterSql($_POST['role_name']), filterSql($_POST['desc']),);
       $role->updateRole($rolearray);
-      header("Location: base_roleadmin.php?action=list");
+      base_header("Location: base_roleadmin.php?action=list");
       break;
 
     case "deleterole";
@@ -106,7 +104,7 @@
       $roleid = filterSql($_GET['roleid']);
       $BRole = new BaseRole();
       $BRole->deleteRole($roleid);
-      header("Location: base_roleadmin.php?action=list");
+      base_header("Location: base_roleadmin.php?action=list");
       break;
     
     case "list";
@@ -123,13 +121,13 @@
         //explode array rows and build table
         $tmpRow = explode("|", $row);
         
-        $tmpHTML = $tmpHTML . "<tr><td align='center'><a href='base_roleadmin.php?action=editrole&amp;roleid=".$tmpRow[0]."'>";
+        $tmpHTML = $tmpHTML . "<tr><td align='center'><a href='base_roleadmin.php?action=editrole&amp;roleid=".urlencode($tmpRow[0])."'>";
         $tmpHTML = $tmpHTML . "<img src='" . $BASE_urlpath ."/images/button_edit.png' border='0' alt='button_edit'></a></td>";
-        $tmpHTML = $tmpHTML . "<td align='center'><a href='base_roleadmin.php?action=deleterole&amp;roleid=".$tmpRow[0]."'>";
+        $tmpHTML = $tmpHTML . "<td align='center'><a href='base_roleadmin.php?action=deleterole&amp;roleid=".urlencode($tmpRow[0])."'>";
         $tmpHTML = $tmpHTML . "<img src='" . $BASE_urlpath ."/images/button_delete.png' border='0' alt='button_delete'></a></td>";
-        $tmpHTML = $tmpHTML . "<td align='center'>" . $tmpRow[0];
-        $tmpHTML = $tmpHTML . "</td><td align='center'>" . $tmpRow[1];
-        $tmpHTML = $tmpHTML . "</td><td align='center'>" . $tmpRow[2];
+        $tmpHTML = $tmpHTML . "<td align='center'>" . htmlspecialchars($tmpRow[0]);
+        $tmpHTML = $tmpHTML . "</td><td align='center'>" . htmlspecialchars($tmpRow[1]);
+        $tmpHTML = $tmpHTML . "</td><td align='center'>" . htmlspecialchars($tmpRow[2]);
         $tmpHTML = $tmpHTML . "</td></tr>";
       }
       // Footer of table
@@ -139,7 +137,7 @@
       break;
   }
     // Start the output to the page.....
-    PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+    PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
 
     PrintBASEAdminMenuHeader();
 
