@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Index page for the administrative functions
@@ -32,14 +33,13 @@
   // Check role out and redirect if needed -- Kevin
   $roleneeded = 1;
   $BUser = new BaseUser();
-  if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/base_main.php");
+  if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1)) {
+    base_header("Location: ". $BASE_urlpath . "/base_main.php");
   }
     
   $page_title = _BASEADMIN;
     
-    PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+    PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
   
     PrintBASEAdminMenuHeader();
   
