@@ -8,7 +8,8 @@ echo "	<div class='mainheadermenu'>"
 . "	<a class='menuitem' href='$BASE_urlpath/base_qry_main.php?new=1'>"._SEARCH."</a>&nbsp;&nbsp;";
 
 if($Use_Auth_System == 1) {
-	echo "|&nbsp;&nbsp;<a class='menuitem' href='$BASE_urlpath/base_user.php'>"._USERPREF."</A>";
+	echo "|&nbsp;&nbsp;<a class='menuitem' href='$BASE_urlpath/base_user.php'>"._USERPREF."</a>";
+	echo "&nbsp;&nbsp;|&nbsp;&nbsp;<a class='menuitem' href='$BASE_urlpath/base_logout.php'>"._LOGOUT."</a>";
 }
 
 echo "</td>"
