@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: status and event/dns/whois cache maintenance 
@@ -39,24 +40,16 @@
       {
          $usrrole = $BUser->AuthenticateNoCookie(filterSql($_POST['user']), filterSql($_POST['pwd']));
          if ($usrrole == "Failed")
-         {
-            header('HTTP/1.0 401');
-            exit;
-         }
+            base_header('HTTP/1.0 401');
          if ($usrrole > $roleneeded)
-         {
-            header('HTTP/1.0 403');
-            exit;
-         }
+            base_header('HTTP/1.0 403');
       }
       elseif (($BUser->hasRole($roleneeded) == 0))
-      {
-        header("Location: ". $BASE_urlpath . "/index.php");
-      }
+        base_header("Location: ". $BASE_urlpath . "/index.php");
    }
 
   $page_title = _MAINTTITLE;
-  PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+  PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
 
   $submit = ImportHTTPVar("submit", VAR_ALPHA | VAR_SPACE);
 ?>
