@@ -56,14 +56,14 @@ function PrintCleanURL()
   if ( (isset($_GET['asciiclean']) && $_GET['asciiclean'] == 1) || ( isset($_COOKIE['asciiclean']) && ($_COOKIE['asciiclean'] == "clean") && (!isset($_GET['asciiclean'])) ) )
   {
     //create link to non-cleaned payload display
-    $url = '<center><a href="base_qry_alert.php?'.urlencode($query);
+		$url = '<center><a href="base_qry_alert.php?' . $query;
     $url.= '&amp;sort_order='.urlencode($sort_order).'&amp;asciiclean=0">'._QANORMALD.'</a></center>';
     return $url;
   }
   else
   {
     //create link to cleaned payload display
-    $url = '<center><a href="base_qry_alert.php?'.urlencode($query);
+		$url = '<center><a href="base_qry_alert.php?' . $query;
     $url.= '&amp;sort_order='.urlencode($sort_order).'&amp;asciiclean=1">'._QAPLAIND.'</a></center>';
     return $url;
   }
@@ -74,16 +74,45 @@ function PrintBinDownload($db, $cid, $sid){
 // Offering a URL to a download possibility:
     	$query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
 	if ( isset($_GET['asciiclean']) && ($_GET['asciiclean'] == 1) || ( (isset($_COOKIE['asciiclean']) && $_COOKIE['asciiclean'] == "clean") && (!isset($_GET['asciiclean'])) ) ){
-		$url = '<center><a href="base_payload.php?'.urlencode($query);
+		$url = '<center><a href="base_payload.php?' . $query;
 		$url.= '&amp;download=1&amp;cid='.urlencode($cid).'&amp;sid='.urlencode($sid).'&amp;asciiclean=1">Download of Payload</a></center>';
 	} else {
-		$url = '<center><a href="base_payload.php?'.urlencode($query);
+		$url = '<center><a href="base_payload.php?' . $query;
 		$url.= '&amp;download=1&amp;cid='.urlencode($cid).'&amp;sid='.urlencode($sid).'&amp;asciiclean=0">Download of Payload</a></center>';
 	}
 	return $url;
 }
 
-function PrintPcapDownload($db, $cid, $sid){
+function PrintPcapDownload($db, $cid, $sid)
+{
+	if (!isset($db))
+	{
+		error_log("ERROR: \$db is NOT set.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db is NOT set. Ignoring.");
+    $debug_str = "<BR><PRE>\n\n" . debug_print_backtrace() . "\n\n</PRE><BR>\n";
+    ErrorMessage($debug_str);
+	}
+
+
+	if (!isset($db->DB))
+	{
+		error_log("ERROR: \$db->DB is NOT set.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db->DB is NOT set. Ignoring.");
+    $debug_str = "<BR><PRE>\n\n" . debug_print_backtrace() . "\n\n</PRE><BR>\n";
+    ErrorMessage($debug_str);
+	}
+
+	if (!is_array($db->DB->MetaColumnNames('data')))
+	{
+		error_log("ERROR: \$db->DB->MetaColumnNames('data') is NOT an array.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db->DB->MetaColumnNames('data') is NOT an array. Ignoring.");
+		print "<BR><PRE>\n\n";
+		debug_print_backtrace();
+		print "\n\n" ;
+		var_dump($db->DB->MetaColumnNames('data'));
+		print "</PRE><BR>\n\n" ;
+	}
+
 
    if ( !in_array("pcap_header", $db->DB->MetaColumnNames('data')) ||
         !in_array("data_header", $db->DB->MetaColumnNames('data'))) {
@@ -94,10 +123,10 @@ function PrintPcapDownload($db, $cid, $sid){
 
    $query = CleanVariable($_SERVER["QUERY_STRING"], VAR_PERIOD | VAR_DIGIT | VAR_PUNC | VAR_LETTER);
 	if ( (isset($_GET['asciiclean']) && $_GET['asciiclean'] == 1) || ( isset($_COOKIE['asciiclean']) && ($_COOKIE["asciiclean"] == "clean") && (!isset($_GET['asciiclean'])) ) ){
-		$url = '<center><a href="base_payload.php?'.urlencode($query);
+		$url = '<center><a href="base_payload.php?' . $query;
 		$url.= '&amp;download='.urlencode($type).'&amp;cid='.urlencode($cid).'&amp;sid='.urlencode($sid).'&amp;asciiclean=1">Download in pcap format</a></center>';
 	} else {
-		$url = '<center><a href="base_payload.php?'.urlencode($query);
+		$url = '<center><a href="base_payload.php?' . $query;
 		$url.= '&amp;download='.urlencode($type).'&amp;cid='.urlencode($cid).'&amp;sid='.urlencode($sid).'&amp;asciiclean=0">Download in pcap format</a></center>';
 	}
 	return $url;
@@ -248,6 +277,10 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
 
   /* Event */
   $sql2 = "SELECT signature, timestamp FROM acid_event WHERE sid='".filterSql($sid)."' AND cid='".filterSql($cid)."'";
+	if ($debug_mode > 0)
+	{
+		print "<BR><BR>\n\n" . __FILE__ . ":" . __LINE__ . ": DEBUG: \$sql2 = \"$sql2\"<BR><BR>\n\n";
+	}
   $result2 = $db->baseExecute($sql2);
   $myrow2 = $result2->baseFetchRow();
 
@@ -479,6 +512,35 @@ function PrintPacketLookupBrowseButtons($seq, $save_sql, $db, &$previous_button,
    * database schema then we can show mac addresses from `data_header`
    * field from `data` table
    */
+	if (!isset($db))
+	{
+		error_log("ERROR: \$db is NOT set.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db is NOT set. Ignoring.");
+    $debug_str = "<BR><PRE>\n\n" . debug_print_backtrace() . "\n\n</PRE><BR>\n";
+    ErrorMessage($debug_str);
+	}
+
+
+	if (!isset($db->DB))
+	{
+		error_log("ERROR: \$db->DB is NOT set.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db->DB is NOT set. Ignoring.");
+    $debug_str = "<BR><PRE>\n\n" . debug_print_backtrace() . "\n\n</PRE><BR>\n";
+    ErrorMessage($debug_str);
+	}
+
+	if (!is_array($db->DB->MetaColumnNames('data')))
+	{
+		error_log("ERROR: \$db->DB->MetaColumnNames('data') is NOT an array.");
+		ErrorMessage(__FILE__ . ":" . __LINE__ . ": db->DB->MetaColumnNames('data') is NOT an array. Ignoring.");
+    print "<BR><PRE>\n\n";
+		debug_print_backtrace();
+		print "\n\n" ;
+		var_dump($db->DB->MetaColumnNames('data'));
+		print "</PRE><BR>\n\n" ;
+	}
+
+
   if (in_array("data_header", $db->DB->MetaColumnNames('data'))) {
 
      $sql5 = "SELECT data_header FROM data WHERE sid='$sid' AND cid='$cid'";
