@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Displays statistics on the detected alerts   
@@ -39,9 +40,7 @@
   $roleneeded = 10000;
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/index.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/index.php");
 
   $qs = new QueryState();
   $qs->AddCannedQuery("most_frequent", $freq_num_alerts, _MOSTFREQALERTS, "occur_d"); 
@@ -146,14 +145,14 @@
                            " ORDER BY sig_cnt DESC");
   $qro->AddTitle(_SENSOR."&nbsp;#");
   $qro->AddTitle(_NBSOURCEADDR, 
-                "saddr_a", ", count(ip_src) AS saddr_cnt ",
+                "saddr_a", ", count(DISTINCT ip_src) AS saddr_cnt ",
                            " ORDER BY saddr_cnt ASC",
-                "saddr_d", ", count(ip_src) AS saddr_cnt ",
+                "saddr_d", ", count(DISTINCT ip_src) AS saddr_cnt ",
                            " ORDER BY saddr_cnt DESC");
   $qro->AddTitle(_NBDESTADDR, 
-                "daddr_a", ", count(ip_dst) AS daddr_cnt ",
+                "daddr_a", ", count(DISTINCT ip_dst) AS daddr_cnt ",
                            " ORDER BY daddr_cnt ASC",
-                "daddr_d", ", count(ip_dst) AS daddr_cnt ",
+                "daddr_d", ", count(DISTINCT ip_dst) AS daddr_cnt ",
                            " ORDER BY daddr_cnt DESC");
   $qro->AddTitle(_FIRST, 
                 "first_a", ", min(timestamp) AS first_timestamp ",
