@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Displays statistics on the detected alerts   
@@ -39,19 +40,40 @@
   $roleneeded = 10000;
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/index.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/index.php");
 
   $submit = ImportHTTPVar("submit", VAR_ALPHA | VAR_SPACE, array(_SELECTED, _ALLONSCREEN, _ENTIREQUERY));
+  $sort_order=ImportHTTPVar("sort_order", VAR_LETTER | VAR_USCORE);
+  $action = ImportHTTPVar("action", VAR_ALPHA); 
   $qs->MoveView($submit);             /* increment the view if necessary */
 
   $page_title = _CHRTCLASS;
   if ( $qs->isCannedQuery() )
-     PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
-                        $page_title.": ".$qs->GetCurrentCannedQueryDesc(), $cs->GetBackLink(), 1);
+	{
+		if ($action == "")
+		{
+    	PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
+                         $page_title.": ".$qs->GetCurrentCannedQueryDesc(), 
+         	               $cs->GetBackLink(), 1);
+		}
+		else
+		{
+			PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
+                         $page_title.": ".$qs->GetCurrentCannedQueryDesc(), 
+         	               $cs->GetBackLink(), $refresh_all_pages);
+		}
+	}
   else
-     PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+	{
+		if ($action == "")
+		{
+    	PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+		}
+		else
+		{
+			PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
+		}
+	}
   
   /* Connect to the Alert database */
   $db = NewBASEDBConnection($DBlib_path, $DBtype);
@@ -227,6 +249,7 @@
   $qs->PrintBrowseButtons();
   $qs->PrintAlertActionButtons();
   $qs->SaveState();
+	ExportHTTPVar("sort_order", $sort_order);
   echo "\n</FORM>\n";
   
   PrintBASESubFooter();
