@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Displays statistics on the detected source and
@@ -54,9 +55,7 @@
   $port_proto = "TCP";
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/index.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/index.php");
 
   $qs = new QueryState();
   $qs->AddCannedQuery("most_frequent", $freq_num_uports, _MOSTFREQPORTS, "occur_d");
@@ -65,6 +64,9 @@
   $submit = ImportHTTPVar("submit", VAR_ALPHA | VAR_SPACE, array(_SELECTED, _ALLONSCREEN, _ENTIREQUERY));
   $port_type = ImportHTTPVar("port_type", VAR_DIGIT);
   $proto = ImportHTTPVar("proto", VAR_DIGIT);
+	$sort_order=ImportHTTPVar("sort_order", VAR_LETTER | VAR_USCORE);
+  $action = ImportHTTPVar("action", VAR_ALPHA);
+
 
   $qs->MoveView($submit);             /* increment the view if necessary */
 
@@ -93,10 +95,31 @@
   }
 
   if ( $qs->isCannedQuery() )
-     PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
-                        $page_title.": ".$qs->GetCurrentCannedQueryDesc(), $cs->GetBackLink(), 1);
+	{
+		if ($action == "")
+		{
+     	PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
+                         $page_title.": ".$qs->GetCurrentCannedQueryDesc(), 
+                         $cs->GetBackLink(), 1);
+		}
+		else
+		{
+			PrintBASESubHeader($page_title.": ".$qs->GetCurrentCannedQueryDesc(),
+                         $page_title.": ".$qs->GetCurrentCannedQueryDesc(), 
+                         $cs->GetBackLink(), $refresh_all_pages);
+		}
+	}
   else
-     PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+	{
+		if ($action == "")
+		{
+     	PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+		}
+		else
+		{
+			PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
+		}
+	}
 
   if ( $event_cache_auto_update == 1 )  UpdateAlertCache($db);
 
@@ -161,6 +184,7 @@
 
   /* Setup the Query Results Table */
   $qro = new QueryResultsOutput("base_stat_ports.php?caller=$caller".
+                                "&amp;sort_order=".$sort_order.
                                 "&amp;port_type=$port_type&amp;proto=$proto");
 
   $qro->AddTitle(" ");
@@ -274,6 +298,7 @@
                    "&amp;".$url_port_type."_port%5B0%5D%5B5%5D=+".
                    "&amp;".$url_port_type."_port_cnt=1".
                    "&amp;layer4=".$url_layer4.
+                   "&amp;sort_order=".$sort_order.
                    "&amp;num_result_rows=-1&amp;current_view=-1";
 
       qroPrintEntryHeader($i);
@@ -318,6 +343,7 @@
   $qs->SaveState();
   ExportHTTPVar("port_type", $port_type);
   ExportHTTPVar("proto", $proto);
+	ExportHTTPVar("sort_order", $sort_order);	
 
   echo "\n</FORM>\n";
   
