@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Sensor statistics
@@ -41,15 +42,22 @@
   $roleneeded = 10000;
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
-  {
-    header("Location: ". $BASE_urlpath . "/index.php");
-  }
+    base_header("Location: ". $BASE_urlpath . "/index.php");
 
-  $submit = ImportHTTPVar("submit", VAR_LETTER | VAR_SPACE, array(_SELECTED, _ALLONSCREEN, _ENTIREQUERY));
+  $submit = ImportHTTPVar("submit", VAR_ALPHA | VAR_SPACE, array(_SELECTED, _ALLONSCREEN, _ENTIREQUERY));
+	$sort_order=ImportHTTPVar("sort_order", VAR_LETTER | VAR_USCORE);
+  $action = ImportHTTPVar("action", VAR_ALPHA);
   $qs->MoveView($submit);             /* increment the view if necessary */
 
   $page_title = SPSENSORLIST;
-  PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+	if ($action == "")
+	{
+  	PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), 1);
+	}
+	else
+	{
+		PrintBASESubHeader($page_title, $page_title, $cs->GetBackLink(), $refresh_all_pages);
+	}
   
   /* Connect to the Alert database */
   $db = NewBASEDBConnection($DBlib_path, $DBtype);
@@ -147,7 +155,8 @@
   }
 
   /* Print the current view number and # of rows */
-  $qs->PrintResultCnt('<FORM METHOD="post" NAME="PacketForm" ACTION="base_stat_sensor.php">');  
+  $qs->PrintResultCnt();
+  echo '<FORM METHOD="post" NAME="PacketForm" ACTION="base_stat_sensor.php">';
   $qro->PrintHeader();
 
   $i = 0;
@@ -192,7 +201,8 @@
   $qs->PrintBrowseButtons();
   $qs->PrintAlertActionButtons();
   $qs->SaveState();
-  
+	ExportHTTPVar("sort_order", $sort_order);
+  echo "\n</FORM>\n";
   
   PrintBASESubFooter();
 
