@@ -7,6 +7,7 @@
 ** (veja o arquivo 'base_main.php' para detalhes de licença)
 **
 ** Lideranças do Projeto: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Feito a partir do trabalho de Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Propósito: Arquivo da linguagem Português Brasileiro
@@ -616,7 +617,7 @@ DEFINE('_SCPORT','Porta');
 
 //base_stat_ipaddr.php
 DEFINE('_PSEVENTERR','ERRO DE EVENTO PORTSCAN: ');
-DEFINE('_PSEVENTERRNOFILE','Nenhum arquivo foi especificado na variável \$portscan_file.');
+DEFINE('_PSEVENTERRNOFILE','Nenhum arquivo foi especificado na variável $portscan_file.');
 DEFINE('_PSEVENTERROPENFILE','Não foi possível abrir o arquivo de eventos Portscan');
 DEFINE('_PSDATETIME','Data/Hora');
 DEFINE('_PSSRCIP','IP de Origem');
