@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Turkish language file
@@ -608,7 +609,7 @@ DEFINE('_SCPORT','Port');
 
 //base_stat_ipaddr.php
 DEFINE('_PSEVENTERR','PORTSCAN OLAY HATASI: ');
-DEFINE('_PSEVENTERRNOFILE','\$portscan_file deikeninde hibir dosya belirtilmemi');
+DEFINE('_PSEVENTERRNOFILE','$portscan_file deikeninde hibir dosya belirtilmemi');
 DEFINE('_PSEVENTERROPENFILE','Portscan olay dosyasn amak olanaksz');
 DEFINE('_PSDATETIME','Tarih/Zaman');
 DEFINE('_PSSRCIP','Kaynak IP');
